@@ -6,47 +6,46 @@ using System.Drawing;
 using System.Text;
 using System.Windows.Forms;
 
-#region Google Contacts specific imports
+#region Google_Health specific imports
 using Google.GData.Client;
-using Google.GData.Extensions;
-using Google.GData.Contacts;
+using Google.GData.Health;
 using Google.GData.Tools;
 #endregion
 
-namespace Google_ContactsApplication
+namespace Google_HealthApplication
 {
     public partial class Form1 : Form
     {
 
         private String googleAuthToken = null;
-        private ContactsService contactsService = null;
+        private HealthService healthService = null;
 
         public Form1()
         {
             InitializeComponent();
 
-            this.contactsService = new ContactsService("GoogleContactsSample");
+            this.healthService = new HealthService("GoogleHealthSample");
 
             if (this.googleAuthToken == null)
             {
-                GoogleClientLogin loginDialog = new GoogleClientLogin(this.contactsService, "youremailhere@gmail.com");
+                GoogleClientLogin loginDialog = new GoogleClientLogin(this.healthService, "youremailhere@gmail.com");
                 loginDialog.ShowDialog();
 
                 this.googleAuthToken = loginDialog.AuthenticationToken;
 
                 if (this.googleAuthToken != null)
                 {
-                    this.contactsService.SetAuthenticationToken(this.googleAuthToken);
+                    this.healthService.SetAuthenticationToken(this.googleAuthToken);
                     this.Text = "Successfully logged in";
 
-                    ContactsQuery query = new ContactsQuery(ContactsQuery.CreateContactsUri(loginDialog.User));
+                    HealthQuery query = new HealthQuery(HealthQuery.ProfileListFeed);
                     this.listView.Clear();
 
-                    ContactsFeed feed = this.contactsService.Query(query);
+                    HealthFeed feed = this.healthService.Query(query);
 
                     if (feed != null && feed.Entries.Count > 0)
                     {
-                        foreach (ContactEntry entry in feed.Entries)
+                        foreach (HealthEntry entry in feed.Entries)
                         {
                             ListViewItem item = new ListViewItem(entry.Title.Text);
                             item.Tag = entry;
