@@ -17,29 +17,25 @@ using System;
 using Google.GData.Client;
 using Google.GData.Extensions;
 
-namespace Google.GData.ContentForShopping
-{
+namespace Google.GData.ContentForShopping {
     /// <summary>
     /// Feed API customization class for defining Product feed.
     /// </summary>
-    public class ProductFeed : AbstractFeed
-    {
+    public class ProductFeed : AbstractFeed {
         /// <summary>
         /// Constructor
         /// </summary>
         /// <param name="uriBase">The uri for the product feed.</param>
         /// <param name="iService">The ContentForShopping service.</param>
         public ProductFeed(Uri uriBase, IService iService)
-            : base(uriBase, iService)
-        {
+            : base(uriBase, iService) {
         }
 
         /// <summary>
         /// returns a new entry for this feed
         /// </summary>
         /// <returns>AtomEntry</returns>
-        public override AtomEntry CreateFeedEntry()
-        {
+        public override AtomEntry CreateFeedEntry() {
             return new ProductEntry();
         }
     }
