@@ -276,7 +276,8 @@ namespace Google.GData.Client
         public Uri Uri
         {
             get {
-                String uriToUse = this.baseUri == null ? String.Empty : this.baseUri.Replace(this.UnusedProtocol, this.DefaultProtocol);
+                String computedBaseUri = GetBaseUri();
+                String uriToUse = computedBaseUri == null ? String.Empty : computedBaseUri.Replace(this.UnusedProtocol, this.DefaultProtocol);
                 return new Uri(CalculateQuery(uriToUse));
                 }
             
@@ -290,6 +291,13 @@ namespace Google.GData.Client
         }
         /////////////////////////////////////////////////////////////////////////////
 
+        /// <summary>
+        /// Returns the base Uri for the feed.
+        /// </summary>
+        protected virtual string GetBaseUri() {
+            return this.baseUri;
+        }
+
 
         //////////////////////////////////////////////////////////////////////
         /// <summary>accessor method public bool CategoryQueriesAsParameter</summary> 
