@@ -9,89 +9,42 @@ namespace Google.GData.Client {
     /// The original OAuth code from http://eran.sandler.co.il/, hosted at http://oauth.net
     /// Modified only to change namespace.
     /// Written by Eran Sandler (http://eran.sandler.co.il)
+    /// Edited by Claudio Cherubino and Alain Vongsouvanh
     /// </summary>
-	public class OAuthBase {
-
-        /// <summary>
-        /// Provides a predefined set of algorithms that are supported officially by the protocol
-        /// </summary>
-        public enum SignatureTypes {
-            HMACSHA1,
-            PLAINTEXT,
-            RSASHA1
-        }
-
-        /// <summary>
-        /// Provides an internal structure to sort the query parameter
-        /// </summary>
-        protected class QueryParameter {
-            private string name = null;
-            private string value = null;
-
-            public QueryParameter(string name, string value) {
-                this.name = name;
-                this.value = value;
-            }
-
-            public string Name {
-                get { return name; }
-            }
-
-            public string Value {
-                get { return value; }
-            }            
-        }
-
-        /// <summary>
-        /// Comparer class used to perform the sorting of the query parameters
-        /// </summary>
-        protected class QueryParameterComparer : IComparer<QueryParameter> {
-
-            #region IComparer<QueryParameter> Members
-
-            public int Compare(QueryParameter x, QueryParameter y) {
-                if (x.Name == y.Name) {
-                    return string.Compare(x.Value, y.Value);
-                } else {
-                    return string.Compare(x.Name, y.Name);
-                }
-            }
-
-            #endregion
-        }
-
-		protected const string OAuthVersion = "1.0";
-        protected const string OAuthParameterPrefix = "oauth_";
+    public class OAuthBase {
+        public static string OAuthVersion = "1.0";
+        public static string OAuthParameterPrefix = "oauth_";
 
         //
-        // List of know and used oauth parameters' names
+        // List of known and used oauth parameters' names
         //        
-		protected const string OAuthConsumerKeyKey = "oauth_consumer_key";
-		protected const string OAuthCallbackKey = "oauth_callback";
-		protected const string OAuthVersionKey = "oauth_version";
-		protected const string OAuthSignatureMethodKey = "oauth_signature_method";
-		protected const string OAuthSignatureKey = "oauth_signature";
-		protected const string OAuthTimestampKey = "oauth_timestamp";
-		protected const string OAuthNonceKey = "oauth_nonce";
-		protected const string OAuthTokenKey = "oauth_token";
-		protected const string OAuthTokenSecretKey = "oauth_token_secret";
+        public static string OAuthConsumerKeyKey = "oauth_consumer_key";
+        public static string OAuthConsumerSecretKey = "oauth_consumer_secret";
+        public static string OAuthCallbackKey = "oauth_callback";
+        public static string OAuthVersionKey = "oauth_version";
+        public static string OAuthSignatureMethodKey = "oauth_signature_method";
+        public static string OAuthSignatureKey = "oauth_signature";
+        public static string OAuthTimestampKey = "oauth_timestamp";
+        public static string OAuthNonceKey = "oauth_nonce";
+        public static string OAuthTokenKey = "oauth_token";
+        public static string OAuthTokenSecretKey = "oauth_token_secret";
+        public static string OAuthVerifierKey = "oauth_verifier";
+        public static string OAuthScopeKey = "scope";
 
-        protected const string HMACSHA1SignatureType = "HMAC-SHA1";
-        protected const string PlainTextSignatureType = "PLAINTEXT";
-        protected const string RSASHA1SignatureType = "RSA-SHA1";
-
-        protected Random random = new Random();
+        public const string HMACSHA1SignatureType = "HMAC-SHA1";
+        public const string PlainTextSignatureType = "PLAINTEXT";
+        public const string RSASHA1SignatureType = "RSA-SHA1";
 
         protected static string unreservedChars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_.~";
 
         /// <summary>
         /// Helper function to compute a hash value
         /// </summary>
-        /// <param name="hashAlgorithm">The hashing algoirhtm used. If that algorithm needs some initialization, like HMAC and its derivatives, they should be initialized prior to passing it to this function</param>
+        /// <param name="hashAlgorithm">The hashing algorithm used. If that algorithm needs some initialization,
+        /// like HMAC and its derivatives, they should be initialized prior to passing it to this function</param>
         /// <param name="data">The data to hash</param>
         /// <returns>a Base64 string of the hash value</returns>
-        private static string ComputeHash(HashAlgorithm hashAlgorithm, string data)
-        {
+        private static string ComputeHash(HashAlgorithm hashAlgorithm, string data) {
             if (hashAlgorithm == null) {
                 throw new ArgumentNullException("hashAlgorithm");
             }
@@ -107,21 +60,32 @@ namespace Google.GData.Client {
         }
 
         /// <summary>
-        /// Internal function to cut out all non oauth query string parameters (all parameters not begining with "oauth_")
+        /// Overloaded version of GetQueryParameters to work without a IDictionary parameter
         /// </summary>
-        /// <param name="parameters">The query string part of the Url</param>
-        /// <returns>A list of QueryParameter each containing the parameter name and value</returns>
-        private static List<QueryParameter> GetQueryParameters(string parameters) {
-            if (parameters.StartsWith("?")) {
-                parameters = parameters.Remove(0, 1);
+        /// <param name="querystring">The query string part of the Url</param>
+        /// <returns>A sorted dictionary with string keys and values representing the query parameters</returns>
+        public static SortedDictionary<string, string> GetQueryParameters(string querystring) {
+            return GetQueryParameters(querystring, null);
+        }
+
+        /// <summary>
+        /// Internal function to parse query string parameters and merge them with an existing dictionary
+        /// </summary>
+        /// <param name="querystring">The query string part of the Url</param>
+        /// <param name="dict">The dictionary to be merged with the query string parameters</param>
+        /// <returns>A sorted dictionary with string keys and values representing the query parameters merged with
+        /// the values taken from the dictionary passed as parameter</returns>
+        public static SortedDictionary<string, string> GetQueryParameters(string querystring, IDictionary<string, string> dict) {
+            if (querystring.StartsWith("?")) {
+                querystring = querystring.Remove(0, 1);
             }
 
-            List<QueryParameter> result = new List<QueryParameter>();
+            SortedDictionary<string, string> result = (dict == null) ? new SortedDictionary<string, string>() : new SortedDictionary<string, string>(dict);
 
-            if (!string.IsNullOrEmpty(parameters)) {
-                string[] p = parameters.Split('&');
+            if (!string.IsNullOrEmpty(querystring)) {
+                string[] p = querystring.Split('&');
                 foreach (string s in p) {
-                    if (!string.IsNullOrEmpty(s) && !s.StartsWith(OAuthParameterPrefix)) {
+                    if (!string.IsNullOrEmpty(s)) {
                         if (s.IndexOf('=') > -1) {
                             string[] temp = s.Split('=');
                             // now temp[1], the value, might contain encoded data, that would be double encoded later. 
@@ -129,9 +93,13 @@ namespace Google.GData.Client {
                             // the same is true for the name
                             string name = Utilities.UrlDecodedValue(temp[0]);
                             string value = Utilities.UrlDecodedValue(temp[1]);
-                            result.Add(new QueryParameter(name, value));
+                            if (result.ContainsKey(name)) {
+                                result[name] = value;
+                            } else {
+                                result.Add(name, value);
+                            }
                         } else {
-                            result.Add(new QueryParameter(Utilities.UrlDecodedValue(s), string.Empty));
+                            result.Add(Utilities.UrlDecodedValue(s), string.Empty);
                         }
                     }
                 }
@@ -150,6 +118,10 @@ namespace Google.GData.Client {
         /// <param name="value">The value to Url encode</param>
         /// <returns>Returns a Url encoded string</returns>
         public static string EncodingPerRFC3986(string value) {
+            if (string.IsNullOrEmpty(value)) {
+                return string.Empty;
+            }
+
             StringBuilder result = new StringBuilder();
 
             foreach (char symbol in value) {
@@ -162,28 +134,33 @@ namespace Google.GData.Client {
 
             return result.ToString();
         }
-                        
+
         /// <summary>
         /// Normalizes the request parameters according to the spec for the signature generation.
         /// </summary>
-        /// <param name="parameters">The list of parameters already sorted</param>
+        /// <param name="parameters">The sorted dictionary containing parameters</param>
         /// <returns>a string representing the normalized parameters</returns>
-		protected static string NormalizeRequestParameters(IList<QueryParameter> parameters) {			
-			StringBuilder sb = new StringBuilder();
-            QueryParameter p = null;
-            for (int i = 0; i < parameters.Count; i++) {
-                p = parameters[i];
-                sb.AppendFormat(CultureInfo.InvariantCulture, "{0}={1}", 
-                                            EncodingPerRFC3986(p.Name), 
-                                            EncodingPerRFC3986(p.Value));
+        protected static string NormalizeRequestParameters(SortedDictionary<string, string> parameters) {
+            if (parameters.Count == 0) {
+                return "";
+            }
 
-                if (i < parameters.Count - 1) {
+            bool first = true;
+            StringBuilder sb = new StringBuilder();
+            foreach (KeyValuePair<string, string> p in parameters) {
+                if (!first) {
                     sb.Append("&");
                 }
+                first = false;
+
+                sb.AppendFormat(CultureInfo.InvariantCulture,
+                    "{0}={1}",
+                    EncodingPerRFC3986(p.Key),
+                    EncodingPerRFC3986(p.Value));
             }
 
             return sb.ToString();
-		}
+        }
 
         /// <summary>
         /// Generate the signature base that is used to produce the signature
@@ -193,19 +170,28 @@ namespace Google.GData.Client {
         /// <param name="token">The token, if available. If not available pass null or an empty string</param>
         /// <param name="tokenSecret">The token secret, if available. If not available pass null or an empty string</param>
         /// <param name="httpMethod">The http method used. Must be a valid HTTP method verb (POST,GET,PUT, etc)</param>
-        /// <param name="signatureType">The signature type. To use the default values use <see cref="OAuthBase.SignatureTypes">OAuthBase.SignatureTypes</see>.</param>
+        /// <param name="timeStamp">The OAuth timestamp. Must be a valid timestamp and equal or greater than
+        /// timestamps used in previous requests</param>
+        /// <param name="nonce">The OAuth nonce. A random string uniquely generated for each request</param>
+        /// <param name="signatureType">The signature type.</param>
         /// <returns>The signature base</returns>
-        public static string GenerateSignatureBase(Uri url, string consumerKey, string token, string tokenSecret, 
-                                                    string httpMethod, string timeStamp, string nonce, string signatureType) {
-            if (token == null) {
-                token = string.Empty;
-            }
+        public static string GenerateSignatureBase(Uri url, string consumerKey, string token, string tokenSecret,
+            string httpMethod, string timeStamp, string nonce, string signatureType) {
+            OAuthParameters parameters = new OAuthParameters() { 
+                ConsumerKey = consumerKey, Token = token, TokenSecret = tokenSecret, Timestamp = timeStamp, Nonce = nonce, SignatureMethod = signatureType
+            };
+            return GenerateSignatureBase(url, httpMethod, parameters);
+        }
 
-            if (tokenSecret == null) {
-                tokenSecret = string.Empty;
-            }
-
-            if (string.IsNullOrEmpty(consumerKey)) {
+        /// <summary>
+        /// Generate the signature base that is used to produce the signature
+        /// </summary>
+        /// <param name="url">The full url that needs to be signed including its non OAuth url parameters</param>
+        /// <param name="httpMethod">The http method used. Must be a valid HTTP method verb (POST,GET,PUT, etc)</param>       
+        /// <param name="parameters">The OAuth parameters</param>
+        /// <returns>The signature base</returns>
+        public static string GenerateSignatureBase(Uri url, string httpMethod, OAuthParameters parameters) {
+            if (string.IsNullOrEmpty(parameters.ConsumerKey)) {
                 throw new ArgumentNullException("consumerKey");
             }
 
@@ -213,38 +199,30 @@ namespace Google.GData.Client {
                 throw new ArgumentNullException("httpMethod");
             }
 
-            if (string.IsNullOrEmpty(signatureType)) {
-                throw new ArgumentNullException("signatureType");
+            if (string.IsNullOrEmpty(parameters.SignatureMethod)) {
+                throw new ArgumentNullException("signatureMethod");
             }
 
-			string normalizedUrl = null;
-			string normalizedRequestParameters = null;
+            string normalizedUrl = null;
+            string normalizedRequestParameters = null;
 
-            List<QueryParameter> parameters = GetQueryParameters(url.Query);
-            parameters.Add(new QueryParameter(OAuthVersionKey, OAuthVersion));
-            parameters.Add(new QueryParameter(OAuthNonceKey, nonce));
-            parameters.Add(new QueryParameter(OAuthTimestampKey, timeStamp));
-            parameters.Add(new QueryParameter(OAuthSignatureMethodKey, signatureType));
-            parameters.Add(new QueryParameter(OAuthConsumerKeyKey, consumerKey));
+            SortedDictionary<string, string> allParameters = GetQueryParameters(url.Query, parameters.BaseProperties);
 
-            if (!string.IsNullOrEmpty(token)) {
-                parameters.Add(new QueryParameter(OAuthTokenKey, token));
+            if (!allParameters.ContainsKey(OAuthVersionKey)) {
+                allParameters.Add(OAuthVersionKey, OAuthVersion);
             }
-      
-            parameters.Sort(new QueryParameterComparer());
 
             normalizedUrl = string.Format("{0}://{1}", url.Scheme, url.Host);
-            if (!((url.Scheme == "http" && url.Port == 80) || (url.Scheme == "https" && url.Port == 443)))
-            {
+            if (!((url.Scheme == "http" && url.Port == 80) || (url.Scheme == "https" && url.Port == 443))) {
                 normalizedUrl += ":" + url.Port;
             }
             normalizedUrl += url.AbsolutePath;
-            normalizedRequestParameters = NormalizeRequestParameters(parameters);
+            normalizedRequestParameters = NormalizeRequestParameters(allParameters);
 
             StringBuilder signatureBase = new StringBuilder();
             signatureBase.AppendFormat(CultureInfo.InvariantCulture, "{0}&", httpMethod.ToUpper());
             signatureBase.AppendFormat(CultureInfo.InvariantCulture, "{0}&", EncodingPerRFC3986(normalizedUrl));
-            signatureBase.AppendFormat(CultureInfo.InvariantCulture, "{0}",  EncodingPerRFC3986(normalizedRequestParameters));
+            signatureBase.AppendFormat(CultureInfo.InvariantCulture, "{0}", EncodingPerRFC3986(normalizedRequestParameters));
 
             return signatureBase.ToString();
         }
@@ -268,13 +246,17 @@ namespace Google.GData.Client {
         /// <param name="token">The token, if available. If not available pass null or an empty string</param>
         /// <param name="tokenSecret">The token secret, if available. If not available pass null or an empty string</param>
         /// <param name="httpMethod">The http method used. Must be a valid HTTP method verb (POST,GET,PUT, etc)</param>
+        /// <param name="timeStamp">The OAuth timestamp. Must be a valid timestamp and equal or greater than
+        /// timestamps used in previous requests</param>
+        /// <param name="nonce">The OAuth nonce. A random string uniquely generated for each request</param>
         /// <returns>A base64 string of the hash value</returns>
-		public string GenerateSignature(Uri url, string consumerKey, string consumerSecret, string token, string tokenSecret, string httpMethod, string timeStamp, string nonce) {            
-			return GenerateSignature(url, consumerKey, consumerSecret, token, tokenSecret, httpMethod, timeStamp, nonce, SignatureTypes.HMACSHA1);
+        public static string GenerateSignature(Uri url, string consumerKey, string consumerSecret, string token, string tokenSecret,
+            string httpMethod, string timeStamp, string nonce) {
+            return GenerateSignature(url, consumerKey, consumerSecret, token, tokenSecret, httpMethod, timeStamp, nonce, HMACSHA1SignatureType);
         }
 
         /// <summary>
-        /// Generates a signature using the specified signatureType 
+        /// Generates a signature using the specified signatureMethod 
         /// </summary>		
         /// <param name="url">The full url that needs to be signed including its non OAuth url parameters</param>
         /// <param name="consumerKey">The consumer key</param>
@@ -282,29 +264,45 @@ namespace Google.GData.Client {
         /// <param name="token">The token, if available. If not available pass null or an empty string</param>
         /// <param name="tokenSecret">The token secret, if available. If not available pass null or an empty string</param>
         /// <param name="httpMethod">The http method used. Must be a valid HTTP method verb (POST,GET,PUT, etc)</param>
-        /// <param name="signatureType">The type of signature to use</param>
+        /// <param name="timeStamp">The OAuth timestamp. Must be a valid timestamp and equal or greater than
+        /// timestamps used in previous requests</param>
+        /// <param name="nonce">The OAuth nonce. A random string uniquely generated for each request</param>
+        /// <param name="signatureMethod">The type of signature to use</param>
         /// <returns>A base64 string of the hash value</returns>
-		public static string GenerateSignature(Uri url, string consumerKey, string consumerSecret, string token, string tokenSecret, string httpMethod, string timeStamp, string nonce, SignatureTypes signatureType) {
+        public static string GenerateSignature(Uri url, string consumerKey, string consumerSecret, string token,
+            string tokenSecret, string httpMethod, string timeStamp, string nonce, string signatureMethod) {
+            OAuthParameters parameters = new OAuthParameters() { 
+                ConsumerKey = consumerKey, ConsumerSecret = consumerSecret, Token = token, TokenSecret = tokenSecret,
+                Timestamp = timeStamp, Nonce = nonce, SignatureMethod = signatureMethod 
+            };
+            return GenerateSignature(url, httpMethod, parameters);
+        }
 
-            switch (signatureType) {
-                case SignatureTypes.PLAINTEXT:					
-                    return HttpUtility.UrlEncode(string.Format("{0}&{1}", consumerSecret, tokenSecret));
-                case SignatureTypes.HMACSHA1:					
-					string signatureBase = GenerateSignatureBase(url, consumerKey, token, tokenSecret, httpMethod, timeStamp, 
-                                           nonce, HMACSHA1SignatureType);
+        /// <summary>
+        /// Generates a signature using the specified signatureMethod 
+        /// </summary>		
+        /// <param name="url">The full url that needs to be signed including its non OAuth url parameters</param>
+        /// <param name="httpMethod">The http method used. Must be a valid HTTP method verb (POST,GET,PUT, etc)</param>
+        /// <param name="parameters">The OAuth parameters</param>
+        /// <returns>A base64 string of the hash value</returns>
+        public static string GenerateSignature(Uri url, string httpMethod, OAuthParameters parameters) {
+            switch (parameters.SignatureMethod) {
+                case PlainTextSignatureType:
+                    return HttpUtility.UrlEncode(string.Format("{0}&{1}", parameters.ConsumerKey, parameters.TokenSecret));
+                case HMACSHA1SignatureType:
+                    string signatureBase = GenerateSignatureBase(url, httpMethod, parameters);
 
                     HMACSHA1 hmacsha1 = new HMACSHA1();
-                    hmacsha1.Key = Encoding.ASCII.GetBytes(GenerateOAuthSignature(consumerSecret, tokenSecret));
+                    hmacsha1.Key = Encoding.ASCII.GetBytes(GenerateOAuthSignature(parameters.ConsumerSecret, parameters.TokenSecret));
 
-                    return GenerateSignatureUsingHash(signatureBase, hmacsha1);                                        
-                case SignatureTypes.RSASHA1:
+                    return GenerateSignatureUsingHash(signatureBase, hmacsha1);
+                case RSASHA1SignatureType:
                     throw new NotImplementedException();
                 default:
                     throw new ArgumentException("Unknown signature type", "signatureType");
             }
         }
 
-
         /// <summary>
         /// oauth_signature is set to the concatenated encoded values of the Consumer Secret and Token Secret, 
         /// separated by a & character (ASCII code 38), even if either secret is empty. This version calls
@@ -314,13 +312,10 @@ namespace Google.GData.Client {
         /// <param name="consumerSecret"></param>
         /// <param name="tokenSecret"></param>
         /// <returns></returns>
-        public static string GenerateOAuthSignatureEncoded(string consumerSecret, string tokenSecret)
-        {
-            return EncodingPerRFC3986(
-                            GenerateOAuthSignature(consumerSecret, tokenSecret));
+        public static string GenerateOAuthSignatureEncoded(string consumerSecret, string tokenSecret) {
+            return EncodingPerRFC3986(GenerateOAuthSignature(consumerSecret, tokenSecret));
         }
 
-
         /// <summary>
         /// oauth_signature is set to the concatenated encoded values of the Consumer Secret and Token Secret, 
         /// separated by a & character (ASCII code 38), even if either secret is empty. 
@@ -329,34 +324,36 @@ namespace Google.GData.Client {
         /// <param name="consumerSecret"></param>
         /// <param name="tokenSecret"></param>
         /// <returns></returns>
-        public static string GenerateOAuthSignature(string consumerSecret, string tokenSecret)
-        {
+        public static string GenerateOAuthSignature(string consumerSecret, string tokenSecret) {
             return string.Format("{0}&{1}",
-                                 EncodingPerRFC3986(consumerSecret),
-                                 string.IsNullOrEmpty(tokenSecret) ? "" : EncodingPerRFC3986(tokenSecret));
+                EncodingPerRFC3986(consumerSecret),
+                string.IsNullOrEmpty(tokenSecret) ? "" : EncodingPerRFC3986(tokenSecret));
         }
 
-
-
         /// <summary>
         /// Generate the timestamp for the signature        
         /// </summary>
         /// <returns></returns>
-        public virtual string GenerateTimeStamp() {
+        public static string GenerateTimeStamp() {
             // Default implementation of UNIX time of the current UTC time
             TimeSpan ts = DateTime.UtcNow - new DateTime(1970, 1, 1, 0, 0, 0, 0);
-            return Convert.ToInt64(ts.TotalSeconds).ToString();            
+            string timeStamp = ts.TotalSeconds.ToString(CultureInfo.InvariantCulture);
+            // remove any fractions of seconds
+            int pointIndex = timeStamp.IndexOf(".");
+            if (pointIndex != -1) {
+                timeStamp = timeStamp.Substring(0, pointIndex);
+            }
+            return timeStamp;
         }
 
         /// <summary>
         /// Generate a nonce
         /// </summary>
         /// <returns></returns>
-        public virtual string GenerateNonce() {
-            // Just a simple implementation of a random number between 123400 and 9999999
-            return random.Next(123400, 9999999).ToString();            
+        public static string GenerateNonce() {
+            // changed from the original oauth code to use Guid
+            return Guid.NewGuid().ToString().ToLower().Replace("-", "");
         }
-
-	}
+    }
 }
 
