@@ -33,6 +33,7 @@ namespace Google.GData.Apps.GoogleMailSettings
         public const string filterFeedUriSuffix = "/filter";
         public const string sendasFeedUriSuffix = "/sendas";
         public const string forwardingFeedUriSuffix = "/forwarding";
+        public const string webclipFeedUriSuffix = "/webclip";
         public const string popFeedUriSuffix = "/pop";
         public const string imapFeedUriSuffix = "/imap";
         public const string vacationFeedUriSuffix = "/vacation";
@@ -254,6 +255,23 @@ namespace Google.GData.Apps.GoogleMailSettings
 			return QueryExtendedFeed(new Uri(uri), true);
 		}
 
+        /// <summary>
+        /// Enables/disables Google Mail's web clip
+        /// </summary>
+        /// <param name="userName">The user for whom this should be done</param>
+        /// <param name="enable">Whether to enable web clip</param>
+        /// <returns>a <code>AppsExtendedEntry</code> containing the results of the creation</returns>
+        public AppsExtendedEntry UpdateWebclip(string userName, string enable) {
+            Uri webclipUri = new Uri(AppsGoogleMailSettingsNameTable.AppsGoogleMailSettingsBaseFeedUri + "/"
+                + domain + "/" + userName + forwardingFeedUriSuffix);
+            AppsExtendedEntry entry = new AppsExtendedEntry();
+            entry.EditUri = webclipUri;
+            entry.Properties.Add(
+                new PropertyElement(
+                AppsGoogleMailSettingsNameTable.enable, enable));
+            return base.Update((AtomEntry)entry) as AppsExtendedEntry;
+        }
+
         /// <summary>
         /// Updates Google Mail's forwarding rule for the given userName
         /// </summary>
@@ -376,7 +394,7 @@ namespace Google.GData.Apps.GoogleMailSettings
         /// <returns>a <code>AppsExtendedEntry</code> containing the results of the
         /// creation</returns>
 		public AppsExtendedEntry UpdateVacation(string userName, string enable, string subject,
-            string message, string contactsOnly)
+            string message, string contactsOnly, string domainOnly, string startDate, string endDate)
         {
             Uri vacationUri = new Uri(AppsGoogleMailSettingsNameTable.AppsGoogleMailSettingsBaseFeedUri + "/"
                 + domain + "/" + userName + vacationFeedUriSuffix);
@@ -397,6 +415,18 @@ namespace Google.GData.Apps.GoogleMailSettings
                 entry.Properties.Add(
                     new PropertyElement(
                     AppsGoogleMailSettingsNameTable.contactsOnly, contactsOnly));
+            if (!string.IsNullOrEmpty(domainOnly))
+                entry.Properties.Add(
+                    new PropertyElement(
+                    AppsGoogleMailSettingsNameTable.domainOnly, domainOnly));
+            if (!string.IsNullOrEmpty(startDate))
+                entry.Properties.Add(
+                    new PropertyElement(
+                    AppsGoogleMailSettingsNameTable.startDate, startDate));
+            if (!string.IsNullOrEmpty(endDate))
+                entry.Properties.Add(
+                    new PropertyElement(
+                    AppsGoogleMailSettingsNameTable.endDate, endDate));
 			return base.Update((AtomEntry)entry) as AppsExtendedEntry;
         }
 
