@@ -418,7 +418,7 @@ namespace Google.GData.Apps.Groups
             {
                 throw new ArgumentNullException("e");
             }
-            if (e.CreatingEntry == true)
+            if (e.CreatingEntry)
             {
                 e.Entry = new AppsExtendedEntry();
             }
