@@ -56,7 +56,7 @@ namespace Google.GData.Contacts {
          /// <summary>
         /// contacts group base URI 
         /// </summary>
-        public const string groupsBaseUri = "http://www.google.com/m8/feeds/groups/";
+        public const string groupsBaseUri = "https://www.google.com/m8/feeds/groups/";
 
         /// <summary>
         /// sortoder value for sorting by lastmodified
@@ -202,7 +202,8 @@ namespace Google.GData.Contacts {
             {
                 char[] deli = { '?', '&' };
 
-                TokenCollection tokens = new TokenCollection(targetUri.Query, deli);
+                string source = HttpUtility.UrlDecode(targetUri.Query);
+                TokenCollection tokens = new TokenCollection(source, deli);
                 foreach (String token in tokens)
                 {
                     if (token.Length > 0)
@@ -257,7 +258,7 @@ namespace Google.GData.Contacts {
                 newPath.AppendFormat(CultureInfo.InvariantCulture, "sortorder={0}", Utilities.UriEncodeReserved(this.SortOrder));
                 paramInsertion = '&';
             }
-            if (this.ShowDeleted == true)
+            if (this.ShowDeleted)
             {
                 newPath.Append(paramInsertion);
                 newPath.Append("showdeleted=true");
@@ -304,7 +305,7 @@ namespace Google.GData.Contacts {
         /// <summary>
         /// contacts base URI 
         /// </summary>
-        public const string contactsBaseUri = "http://www.google.com/m8/feeds/contacts/";
+        public const string contactsBaseUri = "https://www.google.com/m8/feeds/contacts/";
 
         private string group;
 
@@ -377,7 +378,8 @@ namespace Google.GData.Contacts {
             {
                 char[] deli = { '?', '&' };
 
-                TokenCollection tokens = new TokenCollection(targetUri.Query, deli);
+                string source = HttpUtility.UrlDecode(targetUri.Query);
+                TokenCollection tokens = new TokenCollection(source, deli);
                 foreach (String token in tokens)
                 {
                     if (token.Length > 0)
