@@ -17,100 +17,77 @@
 
 using System;
 using System.IO;
-using System.Xml; 
+using System.Xml;
 using System.Collections;
 using System.Configuration;
-using System.Net; 
+using System.Net;
 using NUnit.Framework;
 using Google.GData.Client;
 using Google.GData.Documents;
 
-
-namespace Google.GData.Client.LiveTests
-{
-    [TestFixture] 
+namespace Google.GData.Client.LiveTests {
+    [TestFixture]
     [Category("AuthenticatorTests")]
-    public class AuthenticatorTestSuite : OAuthTestSuite
-    {
-          //////////////////////////////////////////////////////////////////////
+    public class AuthenticatorTestSuite : OAuthTestSuite {
+        //////////////////////////////////////////////////////////////////////
         /// <summary>default empty constructor</summary> 
         //////////////////////////////////////////////////////////////////////
-        public AuthenticatorTestSuite()
-        {
+        public AuthenticatorTestSuite() {
         }
 
         //////////////////////////////////////////////////////////////////////
         /// <summary>the setup method</summary> 
         //////////////////////////////////////////////////////////////////////
         [SetUp]
-        public override void InitTest()
-        {
+        public override void InitTest() {
             Tracing.TraceCall();
             base.InitTest();
         }
-        /////////////////////////////////////////////////////////////////////////////
 
         ////////////////////////////////////////////////////////////////////
         /// <summary>the end it all method</summary> 
         //////////////////////////////////////////////////////////////////////
         [TearDown]
-        public override void EndTest()
-        {
+        public override void EndTest() {
             Tracing.ExitTracing();
         }
-        /////////////////////////////////////////////////////////////////////////////
-
-
-
-        //////////////////////////////////////////////////////////////////////
-        /// <summary>private void ReadConfigFile()</summary> 
-        /// <returns> </returns>
-        //////////////////////////////////////////////////////////////////////
-        protected override void ReadConfigFile()
-        {
-            base.ReadConfigFile();
-        }
-        /////////////////////////////////////////////////////////////////////////////
 
         //////////////////////////////////////////////////////////////////////
         /// <summary>runs an authentication test with client auth</summary> 
         //////////////////////////////////////////////////////////////////////
         [Test]
-        public void ClientAuthenticatorTest()
-        {
-            Tracing.TraceMsg("Entering ClientAuthenticatorTest");
+        public void ClientLoginAuthenticatorTest() {
+            Tracing.TraceMsg("Entering ClientLoginAuthenticatorTest");
 
-            ClientLoginAuthenticator auth = new ClientLoginAuthenticator(this.ApplicationName,
+            ClientLoginAuthenticator auth = new ClientLoginAuthenticator(
+                this.ApplicationName,
                 ServiceNames.Documents,
                 this.userName,
                 this.passWord);
 
             HttpWebRequest request = auth.CreateHttpWebRequest("GET", new Uri(DocumentsListQuery.documentsBaseUri));
-
             request.Headers.Add(GDataGAuthRequestFactory.GDataVersion, "3.0");
             HttpWebResponse response = request.GetResponse() as HttpWebResponse;
 
-            if (response.StatusCode == HttpStatusCode.Redirect)
-            {
+            if (response.StatusCode == HttpStatusCode.Redirect) {
                 request = WebRequest.Create(response.Headers["Location"]) as HttpWebRequest;
                 auth.ApplyAuthenticationToRequest(request);
 
                 response = request.GetResponse() as HttpWebResponse;
-
             }
+
             Assert.IsTrue(response.StatusCode == HttpStatusCode.OK);
         }
-        /////////////////////////////////////////////////////////////////////////////
 
         //////////////////////////////////////////////////////////////////////
-        /// <summary>runs an authentication test with 2 legged oauth</summary> 
+        /// <summary>runs an authentication test with 2-legged OAuth</summary> 
         //////////////////////////////////////////////////////////////////////
         [Test]
-        public void OAuth2LeggedAuthenticatorTest()
-        {
+        public void OAuth2LeggedAuthenticatorTest() {
             Tracing.TraceMsg("Entering OAuth2LeggedAuthenticationTest");
 
-            OAuth2LeggedAuthenticator auth = new OAuth2LeggedAuthenticator(this.ApplicationName,
+            OAuth2LeggedAuthenticator auth = new OAuth2LeggedAuthenticator(
+                this.ApplicationName,
                 this.oAuthConsumerKey,
                 this.oAuthConsumerSecret,
                 this.oAuthUser,
@@ -119,27 +96,25 @@ namespace Google.GData.Client.LiveTests
             HttpWebRequest request = auth.CreateHttpWebRequest("GET", new Uri("https://www.google.com/calendar/feeds/default/owncalendars/full"));
             HttpWebResponse response = request.GetResponse() as HttpWebResponse;
 
-            if (response.StatusCode == HttpStatusCode.Redirect)
-            {
+            if (response.StatusCode == HttpStatusCode.Redirect) {
                 request = WebRequest.Create(response.Headers["Location"]) as HttpWebRequest;
                 auth.ApplyAuthenticationToRequest(request);
 
                 response = request.GetResponse() as HttpWebResponse;
-
             }
+
             Assert.IsTrue(response.StatusCode == HttpStatusCode.OK);
         }
-        /////////////////////////////////////////////////////////////////////////////
 
         //////////////////////////////////////////////////////////////////////
-        /// <summary>runs an authentication test with 2 legged oauth</summary> 
+        /// <summary>runs an authentication test with 3-legged OAuth</summary> 
         //////////////////////////////////////////////////////////////////////
         [Test]
-        public void OAuth3LeggedAuthenticatorTest()
-        {
+        public void OAuth3LeggedAuthenticatorTest() {
             Tracing.TraceMsg("Entering OAuth3LeggedAuthenticationTest");
 
-            OAuth3LeggedAuthenticator auth = new OAuth3LeggedAuthenticator(this.ApplicationName,
+            OAuth3LeggedAuthenticator auth = new OAuth3LeggedAuthenticator(
+                this.ApplicationName,
                 this.oAuthConsumerKey,
                 this.oAuthConsumerSecret,
                 this.oAuthToken,
@@ -148,17 +123,14 @@ namespace Google.GData.Client.LiveTests
             HttpWebRequest request = auth.CreateHttpWebRequest("GET", new Uri("https://www.google.com/calendar/feeds/default/owncalendars/full"));
             HttpWebResponse response = request.GetResponse() as HttpWebResponse;
 
-            if (response.StatusCode == HttpStatusCode.Redirect)
-            {
+            if (response.StatusCode == HttpStatusCode.Redirect) {
                 request = WebRequest.Create(response.Headers["Location"]) as HttpWebRequest;
                 auth.ApplyAuthenticationToRequest(request);
 
                 response = request.GetResponse() as HttpWebResponse;
-
             }
+
             Assert.IsTrue(response.StatusCode == HttpStatusCode.OK);
         }
-        /////////////////////////////////////////////////////////////////////////////
- 
     }
 }
\ No newline at end of file
