@@ -256,6 +256,14 @@ namespace Google.GData.YouTube {
         /// uploaded element string for playlist feeds
         /// </summary>
         public const string Uploaded = "uploaded";
+        /// <summary>
+        /// yt:rating element string
+        /// </summary>
+        public const string YtRating = "rating";
+        /// <summary>
+        /// yt:accessControl element string
+        /// </summary>
+        public const string AccessControl = "accessControl";
 
         /// <summary>
         /// title for a playlist
@@ -504,7 +512,88 @@ namespace Google.GData.YouTube {
 
     }
 
+    /// <summary>
+    /// The yt:accessControl element indicates whether users are allowed to rate a video,
+    /// rate comments about the video, add a video response to the video or embed the
+    /// video on third-party websites.
+    /// </summary>
+    public class YtAccessControl : SimpleElement {
+        /// <summary>the action xml attribute</summary>
+        private const string actionAttribute = "action";
+        /// <summary>the permission xml attribute</summary>
+        private const string permissionAttribute = "permission";
 
+        /// <summary>the rate action</summary>
+        public const string RateAction = "rate";
+        /// <summary>the comment action</summary>
+        public const string CommentAction = "comment";
+        /// <summary>the commentVote action</summary>
+        public const string CommentVoteAction = "commentVote";
+        /// <summary>the videoRespond action</summary>
+        public const string VideoRespondAction = "videoRespond";
+        /// <summary>the list action</summary>
+        public const string ListAction = "list";
+        /// <summary>the embed action</summary>
+        public const string EmbedAction = "embed";
+        /// <summary>the syndicate action</summary>
+        public const string SyndicateAction = "syndicate";
+
+        /// <summary>the allowed permission</summary>
+        public const string AllowedPermission = "allowed";
+        /// <summary>the denied permission</summary>
+        public const string DeniedPermission = "denied";
+        /// <summary>the moderated permission</summary>
+        public const string ModeratedPermission = "moderated";
+
+        /// <summary>
+        /// default constructor for yt:accessControl.
+        /// </summary>
+        public YtAccessControl()
+            : base(YouTubeNameTable.AccessControl,
+                   YouTubeNameTable.ytPrefix,
+                   YouTubeNameTable.NSYouTube) {
+            this.Attributes.Add(actionAttribute, null);
+            this.Attributes.Add(permissionAttribute, null);
+        }
+
+        /// <summary>
+        /// alternative constructor for yt:accessControl that allows
+        /// to specify initial values.
+        /// </summary>
+        public YtAccessControl(string action, string permission)
+            : base(YouTubeNameTable.AccessControl,
+                   YouTubeNameTable.ytPrefix,
+                   YouTubeNameTable.NSYouTube) {
+            this.Attributes.Add(actionAttribute, action);
+            this.Attributes.Add(permissionAttribute, permission);
+        }
+
+        /// <summary>
+        /// convenience accessor for action.
+        /// </summary>
+        /// <returns></returns>
+        public string Action {
+            get {
+                return this.Attributes[actionAttribute] as string;
+            }
+            set {
+                this.Attributes[actionAttribute] = value;
+            }
+        }
+
+        /// <summary>
+        /// convenience accessor for permission.
+        /// </summary>
+        /// <returns></returns>
+        public string Permission {
+            get {
+                return this.Attributes[permissionAttribute] as string;
+            }
+            set {
+                this.Attributes[permissionAttribute] = value;
+            }
+        }
+    }
 
     /// <summary>
     /// id schema extension describing an ID.
@@ -1276,8 +1365,7 @@ namespace Google.GData.YouTube {
         {}
     }
 
-
-      /// <summary>
+    /// <summary>
     /// Uploaded schema extension describing a YouTube uploaded date
     /// </summary>
     public class Uploaded : SimpleElement
@@ -1360,6 +1448,87 @@ namespace Google.GData.YouTube {
         {}
     }
 
+    /// <summary>
+    /// The yt:rating element contains information about the number of users who gave
+    /// the video a positive or negative rating as well as the totale number of ratings
+    /// that the video received.
+    /// </summary>
+    public class YtRating : SimpleElement {
+        /// <summary>the numLikes xml attribute </summary>
+        private const string numLikesAttribute = "numLikes";
+        /// <summary>the numDislikes xml attribute</summary>
+        private const string numDislikesAttribute = "numDislikes";
+        /// <summary>the value xml attribute</summary>
+        private const string valueAttribute = "value";
+        
+        /// <summary>the like video rating</summary>
+        public const string Like = "like";
+        /// <summary>the dislike video rating</summary>
+        public const string Dislikes = "dislikes";
+
+        /// <summary>
+        /// default constructor for yt:rating.
+        /// </summary>
+        public YtRating()
+            : base(YouTubeNameTable.YtRating,
+                   YouTubeNameTable.ytPrefix,
+                   YouTubeNameTable.NSYouTube) {
+            this.Attributes.Add(numLikesAttribute, null);
+            this.Attributes.Add(numDislikesAttribute, null);
+            this.Attributes.Add(valueAttribute, null);
+        }
+
+        /// <summary>
+        /// default constructor for yt:rating.
+        /// </summary>
+        public YtRating(string value)
+            : base(YouTubeNameTable.YtRating,
+                   YouTubeNameTable.ytPrefix,
+                   YouTubeNameTable.NSYouTube) {
+            this.Attributes.Add(numLikesAttribute, null);
+            this.Attributes.Add(numDislikesAttribute, null);
+            this.Attributes.Add(valueAttribute, value);
+        }
+
+        /// <summary>
+        /// convenience accessor for Likes Count.
+        /// </summary>
+        /// <returns></returns>
+        public string NumLikes {
+            get {
+                return this.Attributes[numLikesAttribute] as string;
+            }
+            set {
+                this.Attributes[numLikesAttribute] = value;
+            }
+        }
+
+        /// <summary>
+        /// convenience accessor for Dislikes Count.
+        /// </summary>
+        /// <returns></returns>
+        public string NumDislikes {
+            get {
+                return this.Attributes[numDislikesAttribute] as string;
+            }
+            set {
+                this.Attributes[numDislikesAttribute] = value;
+            }
+        }
+
+        /// <summary>
+        /// The positive ("like") or negative ("dislike") rating for the video.
+        /// </summary>
+        /// <returns></returns>
+        public string RatingValue {
+            get {
+                return this.Attributes[valueAttribute] as string;
+            }
+            set {
+                this.Attributes[valueAttribute] = value;
+            }
+        }
+    }
 
     /// <summary>
     /// Simple class to hold the response of a browser-based upload request
@@ -1430,7 +1599,4 @@ namespace Google.GData.YouTube {
         }
 
     }
-    
-
-
 }
